#! /usr/bin / env node
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "path", "fs", "@clack/prompts", "@clack/prompts", "child_process"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    const args = process.argv.slice(2);
    let supportedArgs = ['--use-npm', '--use-yarn', '--help', '-h', '--use-pnpm', '--app', '--page'];
    const path_1 = __importDefault(require("path"));
    const fs_1 = __importDefault(require("fs"));
    const prompts_1 = require("@clack/prompts");
    const prompts_2 = require("@clack/prompts");
    const child_process_1 = require("child_process");
    function installDependencies(projectName, installationMethod) {
        const projectPath = path_1.default.join(process.cwd(), projectName);
        // try {
        //   execSync(`cd ${projectPath} && yarn`);
        //   console.log('Yarn command executed successfully.');
        // } catch (error) {
        //   console.error(`Error executing yarn: ${error}`);
        // }
        process.on('SIGINT', function () {
            (0, prompts_1.cancel)('Operation cancelled.');
            process.exit(0);
        });
        const s = (0, prompts_1.spinner)();
        s.start('⏳ Installing dependencies...');
        try {
            (0, child_process_1.spawnSync)(`git init && ${installationMethod} && touch .gitignore
    echo "node_modules .next" >> .gitignore`, {
                cwd: projectPath,
                stdio: 'inherit',
                shell: true,
            });
            s.stop(`\x1b[32mSuccess! Created ${projectName} at ${projectPath}\x1b[0m`);
        }
        catch (err) {
            prompts_1.log.error(`\x1b[31mError: ${err}\x1b[0m`);
            prompts_1.log.error('\x1b[31mError installing dependencies:\x1b[0m');
            prompts_1.log.warning(` - Run \x1b[33m yarn \x1b[0m manually!`);
            throw new Error('Error installing dependencies.');
        }
    }
    function main() {
        return __awaiter(this, void 0, void 0, function* () {
            process.on('SIGINT', function () {
                (0, prompts_1.cancel)('Operation cancelled.');
                process.exit(0);
            });
            let projectName = '', installationMethod = 'npm install';
            let useAppRouter;
            if (args.length > 0) {
                if (!(args[0].startsWith('-') || args[0].startsWith('--'))) {
                    if (typeof args[0] === 'string') {
                        projectName = args[0];
                    }
                }
            }
            for (let i = projectName !== '' ? 1 : 0; i < args.length; i++) {
                if (supportedArgs.includes(args[i])) {
                    if (args[i] === '--help' || args[i] === '-h') {
                        console.log(`
              Usage: create-next-app-with-gluestack-ui [project-name] [options]

              Options:
                -h, --help          output usage information
                --use-npm           use npm to install dependencies
                --use-yarn          use yarn to install dependencies
                --use-pnpm          use pnpm to install dependencies
              `);
                        process.exit(0);
                    }
                    else if (args[i] === '--use-npm') {
                        installationMethod = 'npm install --legacy-peer-deps';
                    }
                    else if (args[i] === '--use-yarn') {
                        installationMethod = 'yarn';
                    }
                    else if (args[i] === '--use-pnpm') {
                        installationMethod = 'pnpm i --lockfile-only';
                    }
                    else if (args[i] === '--app') {
                        useAppRouter = 'yes';
                    }
                    else if (args[i] === '--page') {
                        useAppRouter = 'no';
                    }
                }
                else {
                    prompts_1.log.warning(`Unsupported argument: ${args[i]}. For more information run npx create-next-app-with-gluestack-ui --help`);
                    if (!(args[i].startsWith('-') || args[i].startsWith('--'))) {
                        prompts_1.log.warning(`Please pass project name as first argument.`);
                    }
                    process.exit(0);
                }
            }
            let projectPath = path_1.default.join(path_1.default.resolve(__dirname, '..'), 'src', 'page-router');
            if (projectName === '') {
                projectName = yield (0, prompts_1.text)({
                    message: 'What is the \x1b[36m name \x1b[36m of your application?',
                    placeholder: 'my-app',
                    defaultValue: 'my-app',
                    // validate(value) {
                    //   if (value.length === 0) return `Value is required!`;
                    // },
                });
                if ((0, prompts_1.isCancel)(projectName)) {
                    (0, prompts_1.cancel)('Operation cancelled.');
                    process.exit(0);
                }
            }
            if (!useAppRouter) {
                useAppRouter = yield (0, prompts_2.select)({
                    message: 'Would you like to use \x1b[36mApp Router?\x1b[36m',
                    options: [
                        {
                            value: 'no',
                            label: 'No',
                            hint: 'Next js page routing',
                        },
                        {
                            value: 'yes',
                            label: 'Yes',
                            hint: 'Next versions 13.4 and React server components support (Experimental)',
                        },
                    ],
                });
                if ((0, prompts_1.isCancel)(useAppRouter)) {
                    (0, prompts_1.cancel)('Operation cancelled.');
                    process.exit(0);
                }
            }
            if (useAppRouter === 'yes') {
                projectPath = path_1.default.join(path_1.default.resolve(__dirname, '..'), 'src', 'app-router');
            }
            // copy directory
            const data = fs_1.default.cpSync(projectPath, path_1.default.join(process.cwd(), projectName), {
                recursive: true,
            });
            prompts_1.log.info(` Using \x1b[33m ${installationMethod} \x1b!`);
            installDependencies(projectName, installationMethod);
        });
    }
    main();
});
